# coding=utf-8

from django.db import models
from django.conf import settings

from apps.foundation.models import Option
from apps.images.models import Images
from apps.customer.models import Customer, CustomerAddress


class Product(models.Model):
    category = models.ForeignKey(Option, verbose_name=u'类别', on_delete=models.PROTECT)
    name = models.CharField(max_length=255, verbose_name=u"名称")
    describe = models.CharField(verbose_name=u'介绍', max_length=500, null=True, blank=True)
    price = models.BigIntegerField(verbose_name=u'价格', default=0)
    enabled = models.BooleanField(verbose_name=u"在用", default=True)
    cover = models.ForeignKey(Images, verbose_name=u'封面图', on_delete=models.PROTECT, related_name=u'product_thumbnail', null=True)
    notes = models.CharField(max_length=500, verbose_name=u"备注", blank=True, null=True)

    create_user = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=u'创建人', editable=False, on_delete=models.PROTECT)
    create_time = models.DateTimeField(verbose_name=u"添加时间", auto_now_add=True, editable=False)

    delete = models.BooleanField(verbose_name=u"删除", default=False, editable=False)

    class Meta:
        db_table = "product"
        verbose_name = u"商品"
        ordering = ('-id',)
        default_permissions = ()


class ProductImg(models.Model):
    product = models.ForeignKey(Product, verbose_name=u'商品', on_delete=models.PROTECT)
    img = models.ForeignKey(Images, verbose_name=u'图片', on_delete=models.PROTECT)

    class Meta:
        db_table = 'product_img'
        verbose_name = u'商品图片'
        default_permissions = ()


class ProductOrder(models.Model):
    WAIT_PAY = 1
    PAID = 2
    FINISHED = 3
    STATUS_CHOICES = (
        (WAIT_PAY, u'待支付'),
        (PAID, u'已支付'),
        (FINISHED, u'已完成'),
    )
    product = models.ForeignKey(Product, verbose_name=u'商品', on_delete=models.PROTECT)
    create_time = models.DateTimeField(verbose_name=u"添加时间", auto_now_add=True, editable=False)
    no = models.CharField(max_length=64, verbose_name=u"单号", null=True, editable=False, blank=True)
    status = models.PositiveSmallIntegerField(choices=STATUS_CHOICES, verbose_name=u'状态', default=WAIT_PAY)
    customer = models.ForeignKey(Customer, verbose_name=u'客户', on_delete=models.PROTECT, editable=False)
    customer_address = models.ForeignKey(CustomerAddress, verbose_name=u'收货信息', on_delete=models.PROTECT, editable=False)
    count = models.IntegerField(verbose_name=u'购买数量')
    price = models.BigIntegerField(verbose_name=u'单价', editable=False)
    amount = models.BigIntegerField(verbose_name=u'合计金额', editable=False)
    notes = models.CharField(max_length=1000, verbose_name=u'备注', null=True)
    delete = models.BooleanField(verbose_name=u'删除', default=False, editable=False)

    class Meta:
        db_table = 'product_order'
        verbose_name = u'商品订单'
        default_permissions = ()